/*
 * 	Doku, siehe http://www.mikrocontroller.net/articles/AVR_FAT32
 *  Neuste Version: http://www.mikrocontroller.net/svnbrowser/avr-fat32/
 *	Autor: Daniel R.
 */


#ifndef _MMC_H
	#define _MMC_H

	// timer variable ( 10 ms intervall)
	extern volatile unsigned char TimingDelay;

	//Define a function that waits until SPI interface is idle
	#define SPIC_Busy()    while ((SPIC.STATUS & SPI_IF_bm)==0);

	#define MMC_Write			PORTC.OUT	//Port an der die MMC/SD-Karte angeschlossen ist also des SPI
	#define MMC_Read			PORTC.IN
	#define MMC_Direction_REG 	PORTC.DIR

	// da der SPI port ein master gesteuerter port ist, beziehen sich die bezeichnungen auf den master, also den controller.
	// MISO -> Master In Slave Out, also der eingang am MC und der ausgang der karte.
	// MOSI -> Master Out Slave In, also der ausgang am MC und der eingang der karte.
	// der SS pin des SPI ports wird nicht benutzt! also da nich die karte anschließen, sondern an MMC_Chip_Select !

	#define SDCARD_MISO 			6  //Port Pin an dem Data Output der MMC/SD-Karte angeschlossen ist
	#define SDCARD_MOSI				5  //Port Pin an dem Data Input der MMC/SD-Karte angeschlossen ist
	#define SDCARD_Clock 			7  //Port Pin an dem die Clock der MMC/SD-Karte angeschlossen ist (clk)
	#define SDCARD_SS    			4  //Port Pin an dem Chip Select der MMC/SD-Karte angeschlossen ist (CS)


	// prototypen
	extern unsigned char 		mmc_init(void);		// initialisiert die pins und geschwindigkeit
	extern unsigned char 		mmc_read_sector (unsigned long addr,unsigned char *Buffer);	// liest einen sektor mit adresse addr auf Buffer
	extern unsigned char 		mmc_write_sector (unsigned long addr,unsigned char *Buffer);	// schreibt einen sektor mit der adresse addr aus dem puffer Buffer, auf die karte
	extern unsigned char		mmc_multi_block_stop_read (void);						// stop kommando fuer multiblock read operation
	extern unsigned char		mmc_multi_block_stop_write (void);						// stop kommando fuer multiblock write operation
	extern unsigned char 		mmc_multi_block_start_read (unsigned long int addr);	// hier wird das kommando um mehrer bloecke am stueck zu lesen gesendet. ab addr
	extern void 				mmc_multi_block_read_sector (unsigned char *Buffer);	// hiermit werden nacheinander die bloecke gelesen
	extern unsigned char 		mmc_multi_block_start_write (unsigned long int addr);	// hier wird das kommando um mehrere bloecke am stueck zu schreiben gesendet, ab addr
	extern unsigned char		mmc_multi_block_write_sector (unsigned char *Buffer);	// hiermit werden nacheinander die bloecke geschrieben

	#if(MMC_STATUS_INFO==TRUE)
		#define MMC_OK			0
		#define MMC_ERROR_1		1
		#define MMC_ERROR_2		2
		#define MMC_NO_CARD		5
		#define MMC_WP			6

		#define MMC_NOT_PRESENT		7
		#define MMC_PROTECTED		8


		#if(MMC_STATUS_INFO == TRUE)
		  extern unsigned char mmc_present(void);
		#endif

		#if(MMC_STATUS_INFO == TRUE && MMC_WRITE == TRUE)
		  extern unsigned char mmc_protected(void);
		#endif
	#endif


#endif
